==> libxkbcommon-doc-1.11.0-1-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/pages_12.js <==
var searchData=
[
  ['i_20break_20a_20latch_20before_20triggering_20another_20latch_20or_20lock_0',['How do I break a latch before triggering another latch or lock?',['../faq.html#how-do-i-break-a-latch-before-triggering-another-latch-or-lock',1,'']]],
  ['i_20customize_20my_20layout_1',['How do I customize my layout?',['../faq.html#how-do-i-customize-my-layout',1,'']]],
  ['i_20swap_20some_20keys_2',['How do I swap some keys?',['../faq.html#how-do-i-swap-some-keys',1,'']]],
  ['i_20test_20my_20custom_20layout_20without_20installing_20it_3',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
  ['identifier_4',['XKB-949 – Invalid identifier',['../error-index.html#XKB-949',1,'']]],
  ['ignored_5',['XKB-516 – Extra symbols ignored',['../error-index.html#XKB-516',1,'']]],
  ['illegal_20key_20type_20preserve_20result_6',['XKB-195 – Illegal key type preserve result',['../error-index.html#XKB-195',1,'']]],
  ['illegal_20keycode_20alias_7',['XKB-101 – Illegal keycode alias',['../error-index.html#XKB-101',1,'']]],
  ['implementations_8',['xkbcomp and libxkbcommon implementations',['../keymap-text-format-v1-v2.html#xkbcommon-vmod-encoding',1,'']]],
  ['in_20key_20type_9',['XKB-971 – Undeclared modifiers in key type',['../error-index.html#XKB-971',1,'']]],
  ['in_20settings_10',['Built-in settings',['../keymap-text-format-v1-v2.html#built-in-settings',1,'']]],
  ['include_11',['include',['../keymap-text-format-v1-v2.html#example-simple-include',1,'Example: simple include'],['../error-index.html#XKB-386',1,'XKB-386 – Recursive include']]],
  ['include_20mechanism_12',['The include mechanism',['../keymap-text-format-v1-v2.html#xkb-include',1,'']]],
  ['include_20path_20list_13',['Example: include path list',['../keymap-text-format-v1-v2.html#example-include-path-list',1,'']]],
  ['include_20statement_14',['XKB-203 – Invalid include statement',['../error-index.html#XKB-203',1,'']]],
  ['included_20file_15',['XKB-661 – Invalid included file',['../error-index.html#XKB-661',1,'']]],
  ['included_20file_20not_20found_16',['XKB-338 – Included file not found',['../error-index.html#XKB-338',1,'']]],
  ['incompatible_20actions_20and_20keysyms_20count_17',['XKB-693 – Incompatible actions and keysyms count',['../error-index.html#XKB-693',1,'']]],
  ['incompatible_20keymap_20text_20format_18',['XKB-742 – Incompatible keymap text format',['../error-index.html#XKB-742',1,'']]],
  ['index_19',['Index',['../error-index.html#error-code-list',1,'']]],
  ['index_20',['index',['../error-index.html',1,'Error index'],['../error-index.html#XKB-237',1,'XKB-237 – Unsupported group index'],['../error-index.html#XKB-903',1,'XKB-903 – Missing symbols group name index']]],
  ['index_20percent_20expansion_21',['XKB-762 – Rules invalid layout index percent expansion',['../error-index.html#XKB-762',1,'']]],
  ['ineffectual_20actions_22',['Ineffectual actions',['../keymap-text-format-v1-v2.html#ineffectual-actions',1,'']]],
  ['infer_20key_20type_23',['XKB-183 – Cannot infer key type',['../error-index.html#XKB-183',1,'']]],
  ['installing_20it_24',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
  ['insufficient_20buffer_20size_25',['XKB-134 – Insufficient buffer size',['../error-index.html#XKB-134',1,'']]],
  ['integer_20overflow_26',['XKB-052 – Integer overflow',['../error-index.html#XKB-052',1,'']]],
  ['interpret_20statements_27',['Interpret statements',['../keymap-text-format-v1-v2.html#interpret-statements',1,'']]],
  ['introduction_28',['Introduction',['../md_doc_2quick-guide.html#introduction',1,'']]],
  ['introduction_20to_20the_20xkb_20text_20format_29',['Introduction to the XKB text format',['../keymap-text-format-v1-v2.html#introduction-to-the-xkb-text-format',1,'']]],
  ['introduction_20to_20xkb_30',['Introduction to XKB',['../xkb-intro.html',1,'']]],
  ['invalid_20action_20field_31',['XKB-563 – Invalid action field',['../error-index.html#XKB-563',1,'']]],
  ['invalid_20compose_20syntax_32',['XKB-685 – Invalid compose syntax',['../error-index.html#XKB-685',1,'']]],
  ['invalid_20escape_20sequence_33',['XKB-193 – Invalid escape sequence',['../error-index.html#XKB-193',1,'']]],
  ['invalid_20expression_20type_34',['XKB-784 – Invalid expression type',['../error-index.html#XKB-784',1,'']]],
  ['invalid_20file_20encoding_35',['XKB-542 – Invalid file encoding',['../error-index.html#XKB-542',1,'']]],
  ['invalid_20identifier_36',['XKB-949 – Invalid identifier',['../error-index.html#XKB-949',1,'']]],
  ['invalid_20include_20statement_37',['XKB-203 – Invalid include statement',['../error-index.html#XKB-203',1,'']]],
  ['invalid_20included_20file_38',['XKB-661 – Invalid included file',['../error-index.html#XKB-661',1,'']]],
  ['invalid_20layout_20index_20percent_20expansion_39',['XKB-762 – Rules invalid layout index percent expansion',['../error-index.html#XKB-762',1,'']]],
  ['invalid_20modmap_20entry_40',['XKB-206 – Invalid modmap entry',['../error-index.html#XKB-206',1,'']]],
  ['invalid_20numeric_20keysym_41',['XKB-082 – Invalid numeric keysym',['../error-index.html#XKB-082',1,'']]],
  ['invalid_20operation_42',['XKB-478 – Invalid operation',['../error-index.html#XKB-478',1,'']]],
  ['invalid_20path_43',['XKB-161 – Invalid path',['../error-index.html#XKB-161',1,'']]],
  ['invalid_20real_20modifier_44',['XKB-623 – Invalid real modifier',['../error-index.html#XKB-623',1,'']]],
  ['invalid_20rules_20syntax_45',['XKB-967 – Invalid rules syntax',['../error-index.html#XKB-967',1,'']]],
  ['invalid_20set_20default_20statement_46',['XKB-254 – Invalid set default statement',['../error-index.html#XKB-254',1,'']]],
  ['invalid_20unicode_20escape_20sequence_47',['XKB-607 – Invalid unicode escape sequence',['../error-index.html#XKB-607',1,'']]],
  ['invalid_20value_48',['XKB-796 – Invalid value',['../error-index.html#XKB-796',1,'']]],
  ['invalid_20xkb_20syntax_49',['XKB-769 – Invalid xkb syntax',['../error-index.html#XKB-769',1,'']]],
  ['is_20xkb_50',['What is XKB?',['../faq.html#what-is-xkb',1,'']]],
  ['iso_20lock_51',['ISO lock',['../keymap-text-format-v1-v2.html#iso-lock',1,'ISO lock'],['../todo.html#_todo000015',1,'ISO lock']]],
  ['it_52',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]]
];

==> libxkbcommon-doc-1.12.0-2-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/pages_12.js <==
var searchData=
[
  ['i_20break_20a_20latch_20before_20triggering_20another_20latch_20or_20lock_0',['How do I break a latch before triggering another latch or lock?',['../faq.html#how-do-i-break-a-latch-before-triggering-another-latch-or-lock',1,'']]],
  ['i_20customize_20my_20layout_1',['How do I customize my layout?',['../faq.html#how-do-i-customize-my-layout',1,'']]],
  ['i_20swap_20some_20keys_2',['How do I swap some keys?',['../faq.html#how-do-i-swap-some-keys',1,'']]],
  ['i_20test_20my_20custom_20layout_20without_20installing_20it_3',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
  ['identifier_4',['XKB-949 – Invalid identifier',['../error-index.html#XKB-949',1,'']]],
  ['ignored_5',['XKB-516 – Extra symbols ignored',['../error-index.html#XKB-516',1,'']]],
  ['illegal_20key_20type_20preserve_20result_6',['XKB-195 – Illegal key type preserve result',['../error-index.html#XKB-195',1,'']]],
  ['illegal_20keycode_20alias_7',['XKB-101 – Illegal keycode alias',['../error-index.html#XKB-101',1,'']]],
  ['implementations_8',['xkbcomp and libxkbcommon implementations',['../keymap-text-format-v1-v2.html#xkbcommon-vmod-encoding',1,'']]],
  ['in_20key_20type_9',['XKB-971 – Undeclared modifiers in key type',['../error-index.html#XKB-971',1,'']]],
  ['in_20settings_10',['Built-in settings',['../keymap-text-format-v1-v2.html#built-in-settings',1,'']]],
  ['include_11',['include',['../keymap-text-format-v1-v2.html#example-simple-include',1,'Example: simple include'],['../error-index.html#XKB-386',1,'XKB-386 – Recursive include']]],
  ['include_20mechanism_12',['The include mechanism',['../keymap-text-format-v1-v2.html#xkb-include',1,'']]],
  ['include_20path_20list_13',['Example: include path list',['../keymap-text-format-v1-v2.html#example-include-path-list',1,'']]],
  ['include_20statement_14',['XKB-203 – Invalid include statement',['../error-index.html#XKB-203',1,'']]],
  ['included_20file_15',['XKB-661 – Invalid included file',['../error-index.html#XKB-661',1,'']]],
  ['included_20file_20not_20found_16',['XKB-338 – Included file not found',['../error-index.html#XKB-338',1,'']]],
  ['incompatible_20actions_20and_20keysyms_20count_17',['XKB-693 – Incompatible actions and keysyms count',['../error-index.html#XKB-693',1,'']]],
  ['incompatible_20keymap_20text_20format_18',['XKB-742 – Incompatible keymap text format',['../error-index.html#XKB-742',1,'']]],
  ['index_19',['Index',['../error-index.html#error-code-list',1,'']]],
  ['index_20',['index',['../error-index.html',1,'Error index'],['../error-index.html#XKB-237',1,'XKB-237 – Unsupported group index'],['../error-index.html#XKB-903',1,'XKB-903 – Missing symbols group name index']]],
  ['index_20percent_20expansion_21',['XKB-762 – Rules invalid layout index percent expansion',['../error-index.html#XKB-762',1,'']]],
  ['ineffectual_20actions_22',['Ineffectual actions',['../keymap-text-format-v1-v2.html#ineffectual-actions',1,'']]],
  ['infer_20key_20type_23',['XKB-183 – Cannot infer key type',['../error-index.html#XKB-183',1,'']]],
  ['installing_20it_24',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
  ['insufficient_20buffer_20size_25',['XKB-134 – Insufficient buffer size',['../error-index.html#XKB-134',1,'']]],
  ['integer_20overflow_26',['XKB-052 – Integer overflow',['../error-index.html#XKB-052',1,'']]],
  ['interpret_20statements_27',['Interpret statements',['../keymap-text-format-v1-v2.html#interpret-statements',1,'']]],
  ['introduction_28',['Introduction',['../md_doc_2quick-guide.html#introduction',1,'']]],
  ['introduction_20to_20the_20xkb_20text_20format_29',['Introduction to the XKB text format',['../keymap-text-format-v1-v2.html#introduction-to-the-xkb-text-format',1,'']]],
  ['introduction_20to_20xkb_30',['Introduction to XKB',['../xkb-intro.html',1,'']]],
  ['invalid_20action_20field_31',['XKB-563 – Invalid action field',['../error-index.html#XKB-563',1,'']]],
  ['invalid_20compose_20locale_32',['XKB-679 – Invalid compose locale',['../error-index.html#XKB-679',1,'']]],
  ['invalid_20compose_20syntax_33',['XKB-685 – Invalid compose syntax',['../error-index.html#XKB-685',1,'']]],
  ['invalid_20escape_20sequence_34',['XKB-193 – Invalid escape sequence',['../error-index.html#XKB-193',1,'']]],
  ['invalid_20expression_20type_35',['XKB-784 – Invalid expression type',['../error-index.html#XKB-784',1,'']]],
  ['invalid_20file_20encoding_36',['XKB-542 – Invalid file encoding',['../error-index.html#XKB-542',1,'']]],
  ['invalid_20identifier_37',['XKB-949 – Invalid identifier',['../error-index.html#XKB-949',1,'']]],
  ['invalid_20include_20statement_38',['XKB-203 – Invalid include statement',['../error-index.html#XKB-203',1,'']]],
  ['invalid_20included_20file_39',['XKB-661 – Invalid included file',['../error-index.html#XKB-661',1,'']]],
  ['invalid_20layout_20index_20percent_20expansion_40',['XKB-762 – Rules invalid layout index percent expansion',['../error-index.html#XKB-762',1,'']]],
  ['invalid_20modmap_20entry_41',['XKB-206 – Invalid modmap entry',['../error-index.html#XKB-206',1,'']]],
  ['invalid_20numeric_20keysym_42',['XKB-082 – Invalid numeric keysym',['../error-index.html#XKB-082',1,'']]],
  ['invalid_20operation_43',['XKB-478 – Invalid operation',['../error-index.html#XKB-478',1,'']]],
  ['invalid_20path_44',['XKB-161 – Invalid path',['../error-index.html#XKB-161',1,'']]],
  ['invalid_20real_20modifier_45',['XKB-623 – Invalid real modifier',['../error-index.html#XKB-623',1,'']]],
  ['invalid_20rules_20syntax_46',['XKB-967 – Invalid rules syntax',['../error-index.html#XKB-967',1,'']]],
  ['invalid_20set_20default_20statement_47',['XKB-254 – Invalid set default statement',['../error-index.html#XKB-254',1,'']]],
  ['invalid_20unicode_20escape_20sequence_48',['XKB-607 – Invalid unicode escape sequence',['../error-index.html#XKB-607',1,'']]],
  ['invalid_20value_49',['XKB-796 – Invalid value',['../error-index.html#XKB-796',1,'']]],
  ['invalid_20xkb_20syntax_50',['XKB-769 – Invalid xkb syntax',['../error-index.html#XKB-769',1,'']]],
  ['is_20xkb_51',['What is XKB?',['../faq.html#what-is-xkb',1,'']]],
  ['iso_20lock_52',['ISO lock',['../keymap-text-format-v1-v2.html#iso-lock',1,'ISO lock'],['../todo.html#_todo000015',1,'ISO lock']]],
  ['it_53',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]]
];
